\name{CNVPrior-class}
\alias{CNVPrior-class}
\alias{CNVPrior}
\alias{plot,CNVPrior,missing-method}
\alias{summary,CNVPrior-method}
\alias{setCNVPrior}
\alias{cnPrior}
\docType{class}
\title{Class "CNVPrior"}
\description{
  Represents the prior distribution used to infer copy number from
  targeted deep sequencing.
}
\usage{
setCNVPrior(alpha = 1, beta = 1,
            pAbnormal=2/3, pGain = NULL, pLoss = pGain,
            pMutWrong = 0.01, pSnpWrong = 0.01, resn=300)
cnPrior(object)
\S4method{plot}{CNVPrior,missing}(x, lwd=2, \dots)
\S4method{summary}{CNVPrior}(object, \dots)
}
\arguments{
  \item{alpha}{Parameter for the beta prior distribution on the fraction
    of normal cells.}
  \item{beta}{Parameter for the beta prior distribution on the fraction
    of normal cells.}
  \item{pAbnormal}{Prior probability of an aberration; split equally
    between gain and loss.} 
  \item{pGain}{Prior probability of a gain in copy number.  Defaults to
    NULL, in which case it is set to half of \code{pAbnormal}.}
  \item{pLoss}{Prior probability of a loss of copy number.  Defaults to
    NULL, in which case it is set to half of \code{pAbnormal}.}
  \item{pMutWrong}{Prior probability that something called a somatic
    mutation is actually a known single nucleotide polymorphism (SNP).}
  \item{pSnpWrong}{Prior probability that something called a SNP is
    actually a somatic mutation.}
  \item{resn}{The number of points at which to compute values of the
    beta distribution in order to compute the likelihood and posterior.}
  \item{object}{object of class \code{CNVPrior}.}
  \item{x}{object of class \code{CNVPrior}.}
  \item{\dots}{extra arguments for generic or plotting routines.}
  \item{lwd}{Line width parameter.}
}
\details{
  The \code{DeepCNV} class is used to fit a Bayesian model to targeted
  sequencing data from one or a few genes in order to draw inferences
  about possible copy number changes. Basically, we assume that the
  observed data consists of a list  of triples (K, N, V), one for each
  variant in a gene.  Here K is the number of variant reads, N is the
  total number of reads, and V is the type of each variant (either a
  known SNP or a somatic mutation).  We model (K, N) using a binomial
  distribution, where the 'success' parameter depends (in a
  deterministic way) on the unknown parameters of interest: the fraction
  \eqn{\nu} of normal cells in the sample and the copy number state (Normal,
  Deleted, or Gained).

  The prior distribution consists of a continuous (by default,
  Beta\eqn{(\alpha, \beta)})  distribution on \eqn{\nu} and a discrete
  distribution on the copy number state S.  The discrete distribution
  can be defined either by setting \code{pAbnormal}, in which case the
  probability os divided equally between Deleted and Gained, or by
  setting both \code{pGain} and \code{pLoss}.

  Note that the settings of \code{pGain} and \code{pLoss}, if present,
  override any setting of \code{pAbnormal}.

  One complication arises from the variant type V, which can be observed
  with error.  In some cases, observations of V are compared with a
  matched normal sample of DNA from the same subject, in which case the
  variant type is known with great confidence.  In the absence of
  matched normal samples, however, the variant type may be inferred
  indirectly from an external database like dbSNP, in which case the
  confidence decreases. Our confidence in these calls is represented by
  the prior probabilities assigned in \code{pMutWrong} and
  \code{pSnpWrong}.  For purposes of our analysis, V is a nuisance
  parameter that we mostly try to hide from the user.  However, the full
  structure of the discrete prior is revealed when using the
  \code{summary} method to look at the prior.
}
\section{Slots}{
  \describe{
    \item{\code{discrete}:}{Data frame containing the discrete part of
      the prior.}
    \item{\code{pGain}:}{Prior probability of a gain in copy number.}
    \item{\code{pLoss}:}{Prior probability of a loss of copy number.}
    \item{\code{pMutWrong}}{Prior probability that something called a somatic
      mutation is actually a known single nucleotide polymorphism (SNP).}
    \item{\code{pSnpWrong}}{Prior probability that something called a SNP is
      actually a somatic mutation.}
    \item{\code{alpha}}{Parameter for the beta prior distribution on the
      fraction of normal cells.} 
    \item{\code{beta}}{Parameter for the beta prior distribution on the
      fraction of normal cells.} 
    \item{\code{grid}:}{Realized grid of points at which the continuous
      prior is computed.}
    \item{\code{pdf}:}{Values of the prior distribution at the
      \code{grid} points.}
  }
}
\section{Methods}{
  \describe{
    \item{plot(x, \dots)}{PLots the continuous part of the prior distribution.}
    \item{summary(object, \dots)}{Writes out a table detailing the
      discrete part of the prior distribution.}
  }
}
\value{
  The \code{setCNVPrior} constructor returns a valid object of the
  \code{CNVPrior} class.

  The \code{cnPrior} function returns a vector of length three containing the
  prior probabilities of the copy number states.
}
\author{
  Kevin R. Coombes \email{krc@silicovore.com}
}
\seealso{
    \code{\link{CNVPosterior}}
}
\examples{
prior <- setCNVPrior(alpha=1.2, beta=4.8, pAbnormal=0.6)
cnPrior(prior)
summary(prior)
plot(prior)
}
\keyword{classes}
\keyword{models}
