\name{CNVPosterior-class}
\alias{CNVPosterior-class}
\alias{CNVPosterior}
\alias{plot,CNVPosterior,missing-method}
\alias{hist,CNVPosterior-method}
\alias{summary,CNVPosterior-method}
\alias{as.data.frame,CNVPosteriorSummary-method}
\alias{makeCNVPosterior}
\docType{class}
\title{Class "CNVPosterior"}
\description{
  Represents the posterior distribution used to infer copy number from
  targeted deep sequencing.
}
\usage{
makeCNVPosterior(obs, prior)
\S4method{plot}{CNVPosterior,missing}(x, place="topright", lwd=1, \dots)
\S4method{hist}{CNVPosterior}(x, place="topright", lwd=1, \dots)
\S4method{summary}{CNVPosterior}(object, \dots)
\S4method{as.data.frame}{CNVPosteriorSummary}(x, row.names = NULL, optional = FALSE, \dots)
}
\arguments{
  \item{obs}{Observed read-count data}
  \item{prior}{Prior distribution, represented using the class \code{CNVPrior}.}
  \item{object}{object of class \code{CNVPosterior}}
  \item{x}{object of class \code{CNVPosterior}}
  \item{place}{Character string; where to place the figure legend}
  \item{lwd}{Line width parameter.}
  \item{row.names}{See \code{\link{as.data.frame}}}
  \item{optional}{See \code{\link{as.data.frame}}}
  \item{\dots}{extra arguments for generic or plotting routines}
}
\details{
  The \code{DeepCNV} class is used to fit a Bayesian model to targeted
  sequencing data from one or a few genes in order to draw inferences
  about possible copy number changes. Basically, we assume that the
  observed data consists of a list  of triples (K, N, V), one for each
  variant in a gene.  Here K is the number of variant reads, N is the
  total number of reads, and V is the type of each variant (either a
  known SNP or a somatic mutation).  We model (K, N) using a binomial
  distribution, where the 'success' parameter depends (in a
  deterministic way) on the unknown parameters of interest: the fraction
  \eqn{\nu} of normal cells in the sample and the copy number state (Normal,
  Deleted, or Gained).

  The prior distribution consists of a continuous (by default,
  Beta\eqn{(\alpha, \beta)})  distribution on \eqn{\nu} and a discrete
  distribution on the copy number state S, which are stored ina n object
  of the \code{CNVPrior} class.    The \code{CNVariant} computes the
  success parameter \eqn{\phi} as a function of the observed data
  (K,N,V).  Then \eqn{\phi} and thbe observed data are passed on to the
  \code{cnvLikelihood} function, whcih computes the binomial
  log-likelihood.

  We compute the posterior distribution essentially by brute force, in
  the function \code{makeCNVPosterior}.  We choopse regularly spaced
  grid of points on the inerval (0,1) and evaluate the log-likelihood at
  every grid point foir each conceivable copy number state.  These
  likelihoods are combined with the prior distribution by teh usual
  application of Bayes Rule.

  One complication arises from the variant type V, which can be observed
  with error.  Additioal complications arise because the variant
  (whether SNP or mutation) can turn out to be either the major or minor
  allele. These difficulties are mostly hidden from the user, and
  resolved by  rfeplacing an overabundaqnce of states with the maximu a
  posteriori selection at each variant. This design decision afects the
  structure of the class, which compute multiple forms of the
  likelihood: 
  \enumerate{
    \item \code{hiddenloglike}, for all hidden states
    \item \code{snploglike}, for each variant separately, collapsiong
  hidden states
    \item \code{loglike}, for the unified gene
  }
  and posterior distribution:
  \enumerate{
    \item \code{snppost}, for eqach variant separately
    \item \code{posterior}, for the unified gene
  }

}
\section{Slots}{
  \describe{
    \item{\code{hiddenloglike}:}{Log-likelihood using the hidden
      expanded discrete model}
    \item{\code{snploglike}:}{Log-likelihood for each SNP analyzed one
      at a time}
    \item{\code{snppost}:}{Posterior distribution of parameters for
      each SNP analyzed one at a time}
    \item{\code{loglike}:}{Log-likelihood merging data from all SNPs} 
    \item{\code{posterior}:}{Posterrio distribution merging data from
      all SNPs}
    \item{\code{calls}:}{List of maximu a posterior variant types used
      to collapse the hidden model}
    \item{\code{observed}:}{Observed read data}
    \item{\code{prior}:}{Prior distribution}
  }
}
\section{Methods}{
  \describe{
    \item{plot(x, \dots)}{Prints all the information in the object}
    \item{hist(x, \dots)}{Prints all the information in the object}
    \item{summary(object, \dots)}{Writes out a summary of the object}
  }
}
\value{
  The \code{makeCNVPosterior} constructor returns a valid object of the
  class.

}
\author{
  Kevin R. Coombes \email{krc@silicovore.com}
}
\seealso{
    \code{\link{CNVPosterior}}
}
\examples{
prior <- setCNVPrior(alpha=1.2, beta=4.8, pAbnormal=0.6)
dataset <- simReads(2, 7, 0.17, "Normal")
posterior <- makeCNVPosterior(dataset, prior)
s <- summary(posterior)
s
as.data.frame(s)
plot(posterior)
hist(posterior)
}
\keyword{classes}
\keyword{models}

