\name{MultiCNVPosterior-class}
\alias{MultiCNVPosterior-class}
\alias{multiCNVPosterior}
\alias{plot,MultiCNVPosterior,missing-method}
\alias{summary,MultiCNVPosterior-method}
\docType{class}
\title{Class "MultiCNVPosterior"}
\description{
  Represents the posterior distribution used to infer copy number from
  targeted deep sequencing of multiple genes.
}
\usage{
multiCNVPosterior(obs, prior)
\S4method{summary}{MultiCNVPosterior}(object, \dots)
\S4method{plot}{MultiCNVPosterior,missing}(x, place="topright", lwd=1, \dots)
}
\arguments{
  \item{obs}{List or data frame of observed read-count data}
  \item{prior}{Prior distribution, represented using the class \code{multiCNVPrior}.}
  \item{object}{object of class \code{multiCNVPosterior}}
  \item{x}{object of class \code{CNVPosterior}}
  \item{place}{Character string; where to place the figure legend}
  \item{lwd}{Line width parameter.}
  \item{\dots}{extra arguments for generic or plotting routines}
}
\details{
  The \code{DeepCNV} class is used to fit a Bayesian model to targeted
  sequencing data from one or a few genes in order to draw inferences
  about possible copy number changes. Details on the algorithm can be
  found in \code{CNVPrior} and \code{CNVPosterior} and in the
  vignettes.

  The \code{multiCNVPosterior} function is the constructor for the
  \code{MultiCNVPosterior} class, and it implements the Bayesian
  algorithm on targeted sequencing data from multiple genes. The key
  point is that estimates of the posterior distribution on the fraction
  \eqn{\nu} of normal cells will be much more reliable by combining the
  observed variants from several genes.   In turn, this improved posterior
  can yield better copy number calls for the genes.

  Limitations: In the current implementation, the same discrete prior
  distribution on the colpy number state must be used for all genes.
  However, when multiple genes are sequenced, one should in principle be
  able to use the read depth of different genes to get a better idea of
  which ones are likely to be gained or lost, thus customizing the
  priors (or better yet, formally adding this information to the
  model).   A second shortcoming is that there is currently no easy
  way to convert the joint posterior distribution on the normal fraction
  into an object of the class \code{CNVPrior} to reuse it.

}
\section{Slots}{
  \describe{
    \item{\code{gposts}:}{List of \code{\link{CNVPosterior}} objects,
      one for each gene}
    \item{\code{cps}}{An object of the \code{CNVPosteriorSummary} class.}
  }
}
\section{Methods}{
  \describe{
    \item{summary(object, \dots)}{Writes out a summary of the object}
    \item{plot(x, \dots)}{Plots the posteriro distribution on the normal
      fraction}
  }
}
\value{
  The \code{makemultiCNVPosterior} constructor returns a valid object of the
  class.

}
\author{
  Kevin R. Coombes \email{krc@silicovore.com}
}
\seealso{
    \code{\link{CNVPrior}}, \code{\link{CNVPosterior}}, \code{\link{cnvLikelihood}}
}
\examples{
prior <- setCNVPrior(alpha=1.2, beta=4.8, pAbnormal=0.6)
obs1 <- simReads(1, 9, 0.23, "Normal")
obs2 <- simReads(1, 7, 0.23, "Deleted")
observed <- list(G1 = obs1, G2=obs2)
rm(obs1, obs2)
prior <- setCNVPrior(alpha=1.2, beta=4.8, pAbnormal=0.6)
mpost <- multiCNVPosterior(observed, prior)
summary(mpost)
plot(mpost, main="Posterior Distribution on Nomral Fraction")
}
\keyword{classes}
\keyword{models}

